@@ -1,9 +1,7 @@
-"panellipse" <- function(donnee,col.p,col.j,firstvar,lastvar=ncol(donnee),alpha=0.05,coord=c(1,2),scale.unit=TRUE,nbsimul=500,nbchoix=NULL,group=NULL,name.group=NULL,level.search.desc=0.5,centerbypanelist=TRUE,scalebypanelist=FALSE,name.panelist=FALSE,variability.variable=TRUE,cex=1,color=NULL){
+"panellipse" <- function(donnee,col.p,col.j,firstvar,lastvar=ncol(donnee),alpha=0.05,coord=c(1,2),scale.unit=TRUE,nbsimul=500,nbchoix=NULL,group=NULL,name.group=NULL,level.search.desc=0.2,centerbypanelist=TRUE,scalebypanelist=FALSE,name.panelist=FALSE,variability.variable=TRUE,cex=1,color=NULL){
 
 hotelling <- function(d1,d2,n1=nrow(d1),n2=nrow(d2)){
     k <- ncol(d1)
-#    n1 <- nrow(d1)
-#    n2 <- nrow(d2)
     xbar1 <- apply(d1,2,mean)
     xbar2 <- apply(d2,2,mean)
     dbar <- xbar2-xbar1
@@ -79,18 +77,24 @@ variab.variable <- function(donnee,echantillon,mfa=FALSE,coord=c(1,2),scale.unit
 
   don.interesting <- search.desc(donnee,col.j=col.j,col.p=col.p,firstvar=firstvar,lastvar=lastvar,level=level.search.desc)
   don.interesting <- don.interesting[,c(col.j,col.p,firstvar:ncol(don.interesting))]
+if (!is.null(group)){
+  group.aux = sum((colnames(donnee[,firstvar:lastvar])%in%colnames(don.interesting[,3:ncol(don.interesting)]))[1:group[1]])
+  for (j in 2:length(group)) group.aux = c(group.aux,sum((colnames(donnee[,firstvar:lastvar])%in%colnames(don.interesting[,3:ncol(don.interesting)]))[(sum(group[1:(j-1)])+1):sum(group[1:j])]))
+  group.old = group
+  group = group.aux
+}
   axe <- construct.axes(don.interesting,group=group,name.group=name.group,coord=coord,scale.unit=scale.unit,centerbypanelist=centerbypanelist,scalebypanelist=scalebypanelist)
   labprod = axe$moyen[axe$moyen[,ncol(axe$moyen)]==0,ncol(axe$moyen)-1]
   nbprod = length(labprod)
+  nbjuge = nlevels(as.factor(don.interesting[,1]))
+  if (is.null(nbchoix)) nbchoix = nbjuge
 
 if (length(group)<2) {
   mat = matrix(NA,nbprod,nbprod)
     aa = axe$moyen[-(1:nbprod),]
     for (i in 1:(nbprod-1)){
-      for (j in i:nbprod){
-        if (length(nbchoix)==0) mat[i,j] = mat[j,i] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord])
-        if (length(nbchoix)!=0) mat[i,j] = mat[j,i] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord],nbchoix,nbchoix)
-    }}
+      for (j in i:nbprod) mat[i,j] = mat[j,i] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord],nbchoix,nbchoix)
+    }
     diag(mat)=1
     colnames(mat)=rownames(mat)=labprod
 }
@@ -100,10 +104,8 @@ if (length(group)>1) {
   for (k in 1:length(group)){
     aa = cbind.data.frame(axe$partiel[-(1:length(labprod)),max(coord)*(k-1)+(1:max(coord))],axe$partiel[-(1:length(labprod)),(ncol(axe$partiel)-1):ncol(axe$partiel)])
     for (i in 1:(nbprod-1)){
-      for (j in i:nbprod){
-        if (length(nbchoix)==0) mat[i,j,k] = mat[j,i,k] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord])
-        if (length(nbchoix)!=0) mat[i,j,k] = mat[j,i,k] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord],nbchoix,nbchoix)
-    }}
+      for (j in i:nbprod) mat[i,j,k] = mat[j,i,k] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord],nbchoix,nbchoix)
+    }
     for (i in 1:nbprod) mat[i,i,k]=1
   }
   aa=axe$moyen[-(1:length(labprod)),]
@@ -120,8 +122,7 @@ if (length(group)>1) {
       aa = cbind.data.frame(axe$partiel[-(1:length(labprod)),max(coord)*(k-1)+(1:max(coord))],axe$partiel[-(1:length(labprod)),(ncol(axe$partiel)-1):ncol(axe$partiel)])
       for (kk in (k+1):length(group)){
         aa2 = cbind.data.frame(axe$partiel[-(1:length(labprod)),max(coord)*(kk-1)+(1:max(coord))],axe$partiel[-(1:length(labprod)),(ncol(axe$partiel)-1):ncol(axe$partiel)])
-        if (length(nbchoix)==0) mat2[k,kk,i] = mat2[kk,k,i] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa2[aa2[,ncol(aa2)-1]==labprod[i],coord])
-        if (length(nbchoix)!=0) mat2[k,kk,i] = mat2[kk,k,i] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa2[aa2[,ncol(aa2)-1]==labprod[i],coord],nbchoix,nbchoix)
+        mat2[k,kk,i] = mat2[kk,k,i] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa2[aa2[,ncol(aa2)-1]==labprod[i],coord],nbchoix,nbchoix)
       }}
     for (k in 1:length(group)) mat2[k,k,i]=1
   }
@@ -138,8 +139,10 @@ if (length(group)>1) {
   res <- list()
   res$eig= axe[[length(names(axe))]]
   res$coordinates= axe[-length(names(axe))]
-  if (length(group)<2) res$hotelling=mat
-  if (length(group)>1) res$hotelling=list(bygroup=mat,byproduct=mat2)
+  if (nbchoix!=1){
+    if (length(group)<2) res$hotelling=mat
+    if (length(group)>1) res$hotelling=list(bygroup=mat,byproduct=mat2)
+  }
   if (variability.variable) res$correl <- auxil
   return(res)
 }
