@@ -1,4 +1,4 @@
-"plotellipseinter" <- function(mat,alpha=0.05,coord=c(1,2),nbbloc=1,moy=TRUE,eig,cex=1,color=NULL){
+"plotellipseinter" <- function(mat,alpha=0.05,coord=c(1,2),nbgroup=1,moy=TRUE,eig,cex=1,color=NULL){
 
 #################################################################
 "ellipse" <- function(loc, cov,alpha)
@@ -37,7 +37,7 @@ if (moy == FALSE) {
   matsimul=cbind.data.frame(mat$partiel$simul[,coord],mat$partiel$simul[,ncol(mat$partiel$simul)])
 }  
 nbp <- nrow(matP)
-nbprod <- nbp/nbbloc
+nbprod <- nbp/nbgroup
 coord.ellipse.a.tracer <- matrix(0,402,2*nbp)
 
 p <- 2
@@ -53,20 +53,22 @@ minx <- min(coord.ellipse.a.tracer[,1+2*(0:(nbp-1))],na.rm=TRUE)
 maxx <- max(coord.ellipse.a.tracer[,1+2*(0:(nbp-1))],na.rm=TRUE)
 miny <- min(coord.ellipse.a.tracer[,2*(1:nbp)],na.rm=TRUE)
 maxy <- max(coord.ellipse.a.tracer[,2*(1:nbp)],na.rm=TRUE)
-  par(mar = c(0,0,2,0))
-  senso.label( matP[,1:2], clabel=0, cpoint=0,xlim=c(minx*1.05,maxx*1.05),ylim=c(1.05*miny,1.05*maxy))
+
+  plot(0, 0, xlab = paste("Dim ",coord[1]," (",eig[coord[1],2],"%)",sep=""), ylab = paste("Dim ",coord[2]," (",eig[coord[2],2],"%)",sep=""), xlim = c(minx*1.05,maxx*1.05), ylim = c(1.05*miny,1.05*maxy), col = "white", asp=1)
+  if (moy==TRUE) title(main = "Confidence ellipses for the mean points")
+  if (moy==FALSE) title(main = "Confidence ellipses for the partial points")
+  abline(v=0,lty=2)
+  abline(h=0,lty=2)
   if (moy==FALSE){
     points(matmoyP[,1], matmoyP[,2],cex=0.8*cex,col=color[1:nbprod],pch=15)
     text( matmoyP[,1], matmoyP[,2], matmoyP[,ncol(matmoyP)], cex = 0.8*cex, pos = 4, offset = 0.2,col=color[1:nbprod])
   }
   if (moy==TRUE) text( matP[,1], matP[,2], matP[,ncol(matP)], cex = 0.8*cex, pos = 4, offset = 0.2,col=color[1:nbprod])
-  for (j in 1:nbbloc){
+  for (j in 1:nbgroup){
     for (i in 1:nbprod) {
       points(matP[(j-1)*nbprod+i,1], matP[(j-1)*nbprod+i,2],cex=0.8*cex,col=color[i],pch=20)
       if (moy==FALSE) lines(c(matP[(j-1)*nbprod+i,1],matmoyP[i,1]),c( matP[(j-1)*nbprod+i,2],matmoyP[i,2]),col=color[i],lty=j)
       lines(coord.ellipse.a.tracer[,(1+2*((i+(j-1)*nbprod)-1)):(2*(i+(j-1)*nbprod))],col=color[i],lty=j)
     }
   }
-  if (moy==TRUE) title(main = paste("Confidence ellipses for the mean points: comp ",coord[1]," (",eig[coord[1],2],"%) - comp ",coord[2]," (",eig[coord[2],2],"%)",sep=""))
-  if (moy==FALSE) title(main = paste("Confidence ellipses for the partial points: comp ",coord[1]," (",eig[coord[1],2],"%) - comp ",coord[2]," (",eig[coord[2],2],"%)",sep=""))
 }
