@@ -16,7 +16,7 @@ maxx <- max(mat[1:nbpoint,1],na.rm=TRUE)
 miny <- min(mat[1:nbpoint,2],na.rm=TRUE)
 maxy <- max(mat[1:nbpoint,2],na.rm=TRUE)
 
-  get(getOption("device"))(max(14,eig[coord[1],1]/eig[coord[1],2]*8),8)
+  get(getOption("device"))(width=max(14,eig[coord[1],1]/eig[coord[1],2]*8),height=8)
   plot(0, 0, xlab = paste("Dim ",coord[1]," (",eig[coord[1],2],"%)",sep=""), ylab = paste("Dim ",coord[2]," (",eig[coord[2],2],"%)",sep=""), xlim = c(minx*1.05,maxx*1.05), ylim = c(1.05*miny,1.05*maxy), col = "white", asp=1)
   abline(v=0,lty=2)
   abline(h=0,lty=2)
